pub struct AuthModel {
pub model: String,
pub confidence: SpecProvenance,
pub roles: Vec<AuthRole>,
pub provenance: Option<String>,
pub credibility: Option<f64>,
}Expand description
The auth / permission model inferred from login flows + gated routes.
Fields
model: String"none", "session", "jwt", "oauth", "basic", …
confidence: SpecProvenanceroles: Vec<AuthRole>provenance: Option<String>credibility: Option<f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AuthModel
impl<'de> Deserialize<'de> for AuthModel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthModel
impl JsonSchema for AuthModel
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for AuthModel