pub struct EntityField {
pub name: String,
pub field_type: String,
pub values: Vec<String>,
pub confidence: SpecProvenance,
pub provenance: Option<String>,
pub credibility: Option<f64>,
}Expand description
A field of an Entity.
Fields
name: Stringfield_type: StringCoarse semantic type: "string", "money", "enum", "date",
"bool", "number", "reference", … Free-form so comprehension can
introduce new types without a schema bump.
values: Vec<String>Enumerated values when field_type == "enum".
confidence: SpecProvenanceprovenance: Option<String>credibility: Option<f64>Trait Implementations
Sourceimpl Clone for EntityField
impl Clone for EntityField
Sourcefn clone(&self) -> EntityField
fn clone(&self) -> EntityField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntityField
impl Debug for EntityField
Sourceimpl<'de> Deserialize<'de> for EntityField
impl<'de> Deserialize<'de> for EntityField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EntityField
impl JsonSchema for EntityField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EntityField
impl PartialEq for EntityField
Sourcefn eq(&self, other: &EntityField) -> bool
fn eq(&self, other: &EntityField) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EntityField
impl Serialize for EntityField
impl StructuralPartialEq for EntityField